.. scinumtools documentation master file, created by
   sphinx-quickstart on Fri Jul 14 22:16:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scinumtools's documentation!
=======================================

Python module ``scinumtools`` is an open source collection of various routines used in everyday programming and analysis of numerical simulations. 
Source code and documentation of the ``scinumtools`` package is hosted on `GitHub <https://github.com/vrtulka23/scinumtools>`_ and Python package is available on `PyPi <https://pypi.org/project/scinumtools/>`_.

The module is divided into following sections:

:ref:`solver/index:expression solver`
     
  Universal expression solver that can be easily modified and adapted for other projects

:ref:`units/index:physical units`
     
  Physical routines and manipulation with dimensional quantities

:ref:`materials/index:material properties`

  Calculator of atomic properties from chemical formulas

:ref:`dip/index:dimensional input parameters`
     
  Parser of dimensional input parameters serialization language

:ref:`misc/index:miscellaneous tools`

  A collection of various usefull scripts and patterns for data analysis

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   solver/index
   units/index
   materials/index
   dip/index
   misc/index
   api/modules
   
Indices and tables
^^^^^^^^^^^^^^^^^^

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
